==> healthrian_visualization_support-1.0.12%2B9.tar.gz: lib/src/widgets/channel_with_pivot.dart <==
// ignore_for_file: public_member_api_docs

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';

part 'channel_with_pivot.g.dart';

/// [Channel] is a widget drawing an ecg sequence per channel.
@CopyWith()
class ChannelWithPivot extends StatelessWidget {
  /// [Channel] is a widget that draw a graph of
  /// an ecg sequence by a given [ecgSequence].
  const ChannelWithPivot({
    super.key,
    required this.ecgSequence,
    this.samplingRate = 250,
    this.strokeWidth = 1.5,
    this.color = Colors.black,
    this.isFiltered = true,
    this.isVisibleGrid = false,
    this.measureTime = 60,
    this.maxY = 2,
    this.minY = -2,
    this.pivot = 0,
    this.pivotColor = Colors.red,
    this.pivotStrokeWidth = 0.5,
    this.division = 1,
    this.step = 0,
  });

  final int measureTime;
  final bool isFiltered;
  final double strokeWidth;
  final int samplingRate;
  final List<FlSpot> ecgSequence;
  final bool isVisibleGrid;

  final double pivot;
  final Color pivotColor;
  final double pivotStrokeWidth;

  final double maxY;
  final double minY;

  final Color color;

  final int division;
  final int step;

  @override
  Widget build(BuildContext context) {
    final tic = samplingRate * measureTime / division;
    final start = tic * step;
    final end = tic * (step + 1);

    final isDrawingPivot = pivot != 0 && start <= pivot && pivot < end;

    final ecg = ecgSequence.sublist(start.toInt(), end.toInt());

    final minX = ecg.first.x;
    final maxX = ecg.last.x;

    return LineChart(
      LineChartData(
        minX: minX,
        maxX: maxX,
        minY: isFiltered ? minY : null,
        maxY: isFiltered ? maxY : null,
        backgroundColor: Colors.transparent,
        lineTouchData: LineTouchData(enabled: false),
        gridData: FlGridData(
          show: false,
        ),
        titlesData: FlTitlesData(
          show: false,
        ),
        borderData: FlBorderData(
          show: false,
        ),
        lineBarsData: [
          LineChartBarData(
            spots: ecg,
            color: color,
            isCurved: false,
            barWidth: strokeWidth,
            dotData: FlDotData(
              show: false,
            ),
          ),
          if (isDrawingPivot)
            LineChartBarData(
              spots: [
                FlSpot(pivot, minY),
                FlSpot(pivot, maxY),
              ],
              color: pivotColor,
              isCurved: false,
              barWidth: pivotStrokeWidth,
              dotData: FlDotData(
                show: false,
              ),
            ),
        ],
      ),
      chartRendererKey: UniqueKey(),
      swapAnimationDuration: Duration.zero,
    );
  }
}

==> healthrian_visualization_support-1.0.18%2B9.tar.gz: lib/src/widgets/channel_with_pivot.dart <==
// ignore_for_file: public_member_api_docs

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';

part 'channel_with_pivot.g.dart';

/// [ChannelWithPivot] is a widget drawing an ecg sequence per channel.
@CopyWith()
class ChannelWithPivot extends StatelessWidget {
  /// [ChannelWithPivot] is a widget that draw a graph of
  /// an ecg sequence by a given [ecgSequence].
  const ChannelWithPivot({
    super.key,
    required this.ecgSequence,
    this.samplingRate = 250,
    this.strokeWidth = 1.5,
    this.color = Colors.black,
    this.isFiltered = true,
    this.isVisibleGrid = false,
    this.measureTime = 60,
    this.refreshTime = 0,
    this.maxY = 2,
    this.minY = -2,
    this.pivot = 0,
    this.pivotColor = Colors.red,
    this.pivotStrokeWidth = 0.5,
    this.step = 0,
    this.backgroundColor = Colors.white,
  });

  final double measureTime;
  final double refreshTime;
  final bool isFiltered;
  final double strokeWidth;
  final int samplingRate;
  final List<FlSpot> ecgSequence;
  final bool isVisibleGrid;

  final double pivot;
  final Color pivotColor;
  final double pivotStrokeWidth;

  final Color backgroundColor;

  final double maxY;
  final double minY;

  final Color color;

  final int step;

  @override
  Widget build(BuildContext context) {
    if (ecgSequence.isEmpty) return const SizedBox();
    final tic = samplingRate * measureTime;

    final minX = ecgSequence.first.x;
    final maxX = ecgSequence.first.x + tic;

    return LineChart(
      LineChartData(
        minX: minX,
        maxX: maxX,
        minY: isFiltered ? minY : null,
        maxY: isFiltered ? maxY : null,
        backgroundColor: backgroundColor,
        lineTouchData: LineTouchData(enabled: false),
        gridData: FlGridData(
          show: false,
        ),
        titlesData: FlTitlesData(
          show: false,
        ),
        borderData: FlBorderData(
          show: false,
        ),
        lineBarsData: [
          LineChartBarData(
            spots: ecgSequence,
            color: color,
            isCurved: false,
            barWidth: strokeWidth,
            dotData: FlDotData(show: false),
          ),
          if (pivot != 0)
            LineChartBarData(
              spots: [
                FlSpot(pivot + pivotStrokeWidth / 2, minY),
                FlSpot(pivot + pivotStrokeWidth / 2, maxY),
              ],
              color: pivotColor,
              gradient: LinearGradient(
                colors: [
                  pivotColor,
                  Colors.transparent,
                ],
              ),
              isCurved: false,
              barWidth: pivotStrokeWidth,
              dotData: FlDotData(show: false),
            ),
        ],
      ),
      chartRendererKey: UniqueKey(),
      swapAnimationDuration: Duration.zero,
    );
  }
}
